Welcome to practNLPTools-lite's documentation!
==============================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   cli
   api
   stanford_installing_issues
   issues
   authors
   contributing
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
